@@ -16,8 +16,6 @@ from langchain.chat_models import ChatOpenAI
 import requests
 from bs4 import BeautifulSoup
 
-
-
 from swarms.utils.logger import logger
 class ToolScope(Enum):
     GLOBAL = "global"
@@ -1307,7 +1305,8 @@ from PIL import Image
 from transformers import BlipForConditionalGeneration, BlipProcessor
 
 # from core.prompts.file import IMAGE_PROMPT
-from swarms.prompts.prompts import IMAGE_PROMPT
+# from swarms.agents.prompts import IMAGE_PROMPT
+from swarms.agents.prompts.prompts import IMAGE_PROMPT
 
 from swarms.utils.main import BaseHandler
 
